Learn R Programming

macat (version 1.46.0)

discretize.tscores: Discretize regularized t-scores

Description

discretize.tscores returns a discretized version of the scores in the MACATevalScoring object. Discretization is performed by comparing the value gene-wise (location-wise) with the symmetric upper and lower quantile given by margin (in percent margin/2 lower and upper quantile). discretizeAllClasses produces a flatfile readable by PYTHON.

Usage

discretize.tscores(scores) discretizeAllClasses.tscores(data, chrom, nperms=10, kernel=rbf, kernelparams=NULL, step.width=100000)

Arguments

scores
a MACATevalScoring object obtained from evalScoring
data
a MACATData Object containing all expression values, geneLocations and labels (obtained from preprocessedLoader)
chrom
chromosome that is discretized
nperms
number of permutations for the computation of empirical p values (evalScoring)
kernel
kernel function used for smoothing one of rbf, kNN, basePairDistance or your own
kernelparams
list of parameters for the kernels
step.width
size of a interpolation step in basepairs

Value

discretize.tscores
a vector of discretized tscores
discretizeAllClasses.tscores
creates python flatfiles (see details)

Details

The filename for the python flat files are discrete_chrom__class_ where and

See Also

evalScoring, kernels, pythondata

Examples

Run this code
  #loaddatapkg("stjudem")
  #data(stjude)
  data(stjd)
  # simple scoring with short running time
  scores = evalScoring(stjd, "T", 1, nperms=100, cross.validate=FALSE)
  discrete = discretize.tscores(scores)

Run the code above in your browser using DataLab